/*
 * Copyright 2008 Arthur Renato Mello <arthur@mandriva.com>
 * Copyright 2008 Gustavo Pichorim Boiko <boiko@mandriva.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include "animatedstatus.h"

#include <QPainter>

AnimatedStatus::AnimatedStatus(QPoint pos, QSize size, QFont font, QColor color, QWidget *parent)
: QWidget(parent), m_timeLine(1000, this), m_alpha(1)
{
	connect(&m_timeLine, SIGNAL(valueChanged(qreal)), this,
		SLOT(slotAnimate(qreal)));

	m_font = font;
	m_color = color;

	move(pos);
	resize(size);

	show();
}

AnimatedStatus::~AnimatedStatus()
{
}

void AnimatedStatus::setText(const QString &text)
{
	m_oldText = m_text;
	m_text = text;
	m_alpha = 0;
	m_timeLine.start();
}

void AnimatedStatus::slotAnimate(qreal value)
{
	m_alpha = value;
	update();
}

void AnimatedStatus::paintEvent(QPaintEvent *event)
{
	QPainter p(this);

	if (m_alpha < 1)
	{
		m_color.setAlpha((1-m_alpha) * 254);
		p.setPen(m_color);
		p.setFont(m_font);
		p.drawText(rect(), Qt::AlignLeft | Qt::AlignVCenter, m_oldText);
	}
	m_color.setAlpha(m_alpha * 254);
	p.setPen(m_color);
	p.setFont(m_font);
	p.drawText(rect(), Qt::AlignLeft | Qt::AlignVCenter, m_text);
}
