/*
 * Copyright 2008 Arthur Renato Mello <arthur@mandriva.com>
 * Copyright 2008 Gustavo Pichorim Boiko <boiko@mandriva.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include <QX11Info>

#include "application.h"

#include <stdio.h>
#include <X11/Xlib.h>

Application::Application(bool test)
: KApplication()
{
	mTestSteps.enqueue("kded");
	mTestSteps.enqueue("confupdate");
	mTestSteps.enqueue("kcminit");
	mTestSteps.enqueue("ksmserver");
	mTestSteps.enqueue("wm");
	mTestSteps.enqueue("desktop");

	mKDESplashProgressAtom = XInternAtom(QX11Info::display(),
		"_KDE_SPLASH_PROGRESS", False);

	if(test)
		startTimer(1500);
}

Application::~Application()
{
}

void Application::timerEvent(QTimerEvent *event)
{
	QString state;

	if(!mTestSteps.isEmpty())
		state = mTestSteps.dequeue();
	else
		quit();

	emit gotState(state);
}

bool Application::x11EventFilter(XEvent *e)
{
	if( e->type == ClientMessage &&
		e->xclient.window == QX11Info::appRootWindow() &&
		e->xclient.message_type == mKDESplashProgressAtom)
	{
		QString state(e->xclient.data.b);

		if(state == "desktop")
			quit();

		emit gotState(state);
	}

	return KApplication::x11EventFilter(e);
}
