/*
 * Copyright 2008 Arthur Renato Mello <arthur@mandriva.com>
 * Copyright 2008 Gustavo Pichorim Boiko <boiko@mandriva.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include <stdio.h>
#include <unistd.h>

#include <QDesktopWidget>

#include <kaboutdata.h>
#include <kcmdlineargs.h>

#include "application.h"
#include "mainwidget.h"

int main(int argc, char**argv){
	KAboutData aboutData("kde4-splash-mdv",
						 0,
						 ki18n("KDE Splash Screen"),
						 "0.1",
						 ki18n("A KDE Splash Screen using Qt4"),
						 KAboutData::License_GPL,
						 ki18n("(c) 2008"),
						 ki18n("A KDE Splash Screen using Qt4"),
						 "www.mandriva.com",
						 "arthur@mandriva.com"
						 );

	KCmdLineArgs::init(argc, argv, &aboutData);
	
	KCmdLineOptions options;
	options.add("pid", ki18n("Show splash pid"));
	options.add("test", ki18n("Run in test mode"));
	options.add("theme <argument>", ki18n("Override theme"));

	KCmdLineArgs::addCmdLineOptions(options);

	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();

	pid_t pid = fork();
	if(pid < -1)
	{
		perror( "fork()" );
		return -1;
	}
	if(pid != 0)
	{
		if (args->isSet("pid"))
			printf("%d\n", pid);

		return 0;
	}

	close(0);
	close(1);
	close(2);

	Application app(args->isSet("test"));

	QString theme = args->getOption("theme");
	MainWidget w(theme, QApplication::desktop()->screenGeometry());

	app.setQuitOnLastWindowClosed(true);

	QObject::connect(&app, SIGNAL(gotState(const QString&)), &w, SLOT(activateState(const QString&)));

	return app.exec();
}
