/*
 * Copyright 2008 Arthur Renato Mello <arthur@mandriva.com>
 * Copyright 2008 Gustavo Pichorim Boiko <boiko@mandriva.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#ifndef THEMESETTINGS_H
#define THEMESETTINGS_H

#include <QString>
#include <QList>

#include "imageloader.h"

typedef struct
{
	loadedPixmap pixmap;
	QString step;
} loadedItem;

typedef QList<loadedItem> itemsList;

typedef struct
{
	QRect rect;
	QFont font;
	QColor color;
} statusInfo;

class ThemeSettings
{
	public:
		ThemeSettings(const QString &p_theme, const QSize &p_target);
		~ThemeSettings();

		QMap<QString, QString> getStatusTexts();
		statusInfo getStatusInfo();
		QPixmap getBackground();
		itemsList getItemsList();

	private:
		void readSettings();
		void chooseResolution();
		void loadStatusInfo();

		ImageLoader m_imageLoader;

		QSize m_targetSize;

		QString m_themeName;
		QString m_themePath;

		QStringList m_imagesDefault;
		QStringList m_stepsDefault;
		QMap<QString, QString> m_imagesTexts;

		QString m_bg;

		QSize m_baseSize;

		QString m_svgFile;
		QString m_svgFileNormal;
		QString m_svgFileWide;

		QString m_statusFile;
		statusInfo m_statusInfo;

		bool m_useIconSet;
		int m_items;

		QStringList m_images;
		QStringList m_steps;
		QList<QPoint> m_imagesCoords;
};
#endif
